@@ -91,7 +91,7 @@ class AzureMLLunaUtils(BaseLunaUtils):
                 deployment_target=deployment_target,
                 aks_cluster=aks_cluster)
         
-        service = Model.deploy(ws, self._args.predecessorOperationId, [model], inference_config, deployment_config)
+        service = Model.deploy(ws, self._args.operationId, [model], inference_config, deployment_config)
         service.wait_for_deployment(show_output = True)
 
     def DownloadModel(self, model_path=""):
